@@ -8,8 +8,8 @@ from pathlib import Path
 import time
 
 import dash_bootstrap_components as dbc
-import dash_core_components as dcc
-import dash_html_components as html
+from dash import dcc
+from dash import html
 import plotly.graph_objects as go
 from dash import callback_context
 from dash.dependencies import Input, Output, State
