@@ -3,8 +3,8 @@ from contextlib import redirect_stdout
 
 import dash_antd_components as dac
 import dash_bootstrap_components as dbc
-import dash_core_components as dcc
-import dash_html_components as html
+from dash import dcc
+from dash import html
 import numpy as np
 from alphaDeesp.core.grid2op.Grid2opSimulation import (
     Grid2opSimulation,
