@@ -2,8 +2,8 @@ import json
 import json
 import os
 
-import dash_core_components as dcc
-import dash_html_components as html
+from dash import dcc
+from dash import html
 import numpy as np
 import plotly.graph_objects as go
 from dash import callback_context
