@@ -1,7 +1,7 @@
 import dash_antd_components as dac
 import dash_bootstrap_components as dbc
-import dash_core_components as dcc
-import dash_html_components as html
+from dash import dcc
+from dash import html
 import datetime as dt
 from grid2viz.src.manager import make_episode, make_network_agent_study
 
@@ -486,7 +486,7 @@ def compare_line(episode, timestep):
 
 
 def layout(study_agent, scenario, user_timestep=None):
-    episode = make_episode(study_agent, scenario)
+    episode = make_episode(study_agent, scenario,with_reboot=True)
     if user_timestep is None:
         user_timestep = 1
     network_graph = make_network_agent_study(
